# -*- coding: utf-8 -*-
import logging
from optparse import make_option
from django.core.exceptions import ObjectDoesNotExist
from django.core.management.base import BaseCommand
from mapshop.models import Category, Product, ProductImages, Kiosk , Order, Client
from django.core.files import File
from random import randint
import csv
from django.contrib.auth.models import User

#logger = logging.getLogger(__name__)


class Command(BaseCommand):

    def handle(self, *args, **options):
        
        print 'start'
        Kiosk.objects.all().delete()
        input_file = open("kiosk.csv", "rb")
        rdr = csv.DictReader(input_file, delimiter=';', fieldnames=['mnemonic', 'name', 'address','latitude','longitude'])
        for rec in rdr:
            #try:
            k = Kiosk()
            k.mnemonic = rec['mnemonic']
            k.name = rec['name']
            k.address = rec['address']
            k.latitude = rec['latitude']
            k.longitude = rec['longitude']
            path = 'fixture/kiosk.jpg'
            #import pdb; pdb.set_trace()
            name = 'kiosk.jpg'
            f = open(path, 'r')
            file = File(f)
            k.foto.save(name,file)
            k.save()
            #except:
            print 'kiosk....%s...done' % k.address
        input_file.close()
        print 'done'

'''
import tempfile
from django.core import files
lf = tempfile.NamedTemporaryFile()
for block in open('path','r'):
    if not block:
        break
    lf.write(block)
j.cover.save(file_name, files.File(lf))

'''

       



# -*- coding: utf-8 -*-
from django.contrib import admin

# Register your models here.
from mapshop.models import Product, Category, ProductImages, Kiosk, Order, OrderItem, Client, Preorder
from image_cropping import ImageCroppingMixin
from mptt.admin import MPTTModelAdmin

class ProductAdmin(admin.ModelAdmin):
    list_display = ('name', 'name_slug', 'thumb', 'price', 'rate', 'category', 'ammount')
    list_filter = ('name', 'price', 'rate')
    list_editable = ('ammount',)

class CategoryAdmin(MPTTModelAdmin):
    list_display = ('name', 'name_slug', 'level', 'parent')

class KioskAdmin(ImageCroppingMixin, admin.ModelAdmin):
    pass

admin.site.register(Product, ProductAdmin)
admin.site.register(Category, CategoryAdmin)
admin.site.register(Kiosk, KioskAdmin)


class ProductImagesAdmin(ImageCroppingMixin, admin.ModelAdmin):
    list_display = ('thumb', 'product', 'is_main')


admin.site.register(ProductImages, ProductImagesAdmin)


class OrderItemInline(admin.TabularInline):
    model = OrderItem
    verbose_name_plural = u'Элементы'

class OrderAdmin(admin.ModelAdmin):
    list_display = ('created_at', 'session', 'kiosk', 'client', 'status')
    list_filter = ('status',)
    inlines = [
        OrderItemInline,
    ]


admin.site.register(Order, OrderAdmin)


class OrderItemAdmin(admin.ModelAdmin):
    list_display = ('product', 'order', 'ammount')


admin.site.register(OrderItem, OrderItemAdmin)


class ClientAdmin(admin.ModelAdmin):
    list_display = ('name', 'surname', 'phone', 'email', 'kiosk')


admin.site.register(Client, ClientAdmin)

class PreorderAdmin(admin.ModelAdmin):
    list_display = ('product', 'contact', 'type', 'created_at')
    list_filter = ('type',)

admin.site.register(Preorder, PreorderAdmin)






# -*- coding: utf-8 -*-
from django.shortcuts import render
from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from mapshop.forms import ProductFilterForm
from mapshop.models import Category, Product, Kiosk, Order, Client, get_client_or_create
from mapshop.forms import ClientForm
from django.http import HttpResponseRedirect


import django.dispatch
payment_done = django.dispatch.Signal(providing_args=["order_id"])



def home(request):
    context = {}
    payment_done.send(None,order_id=12)
    print 'my var %s ' % request.supervar
    return render_to_response('mapshop/home.html', context, RequestContext(request))


def product_list(request,slug='all'):
    u''' 
        Список товаров в категории (по умолчанию во всех категориях)
        при передаче параметров sort_price, sort_rate (up/down) сортируем.
    '''
    # initialization
    cur_rate_order = 'asc'
    cur_rate_price = 'asc'
    # get all products
    products = Product.objects.all()
    if slug=='all':
        title = 'Все товары'
        # select all categories 
        category_list = Category.objects.all()
    else:
        
        category =  Category.objects.get(name_slug=slug)
        title = 'Товары из категории "%s"' % category
        # select all categories excluding current
        category_list = Category.objects.all().exclude(name_slug=slug)
        # add filter
        products = products.filter(category=category)

    # handle with order
    try:
        #import pdb; pdb.set_trace()
        rate_order = request.GET['rate_order']
        if rate_order == 'desc':
            products = products.order_by('-rate')
            cur_rate_order = 'desc'
        else:
            products = products.order_by('rate')  
            cur_rate_order = 'asc'
    except:
        pass

    try:
        rate_price = request.GET['price_order']
        if rate_price == 'desc':
            products = products.order_by('-price')
            cur_rate_price = 'desc'
        else:
            products = products.order_by('price')  
            cur_rate_price = 'asc'
    except:
        pass

    #category = Course.objects.get(name=category_name)
    #Author.objects.order_by('-score')[:30]

    ''' avdey code
    filter_form = ProductFilterForm()
    if request.method == 'GET' and bool(request.GET):
        filter_form = ProductFilterForm(request.GET)
    data = dict(filter_form=filter_form)
    return render_to_response('product_list.html', data, RequestContext(request))
    '''

    context = {'title': title, 'category_list': category_list, 'product_list': products, 'cur_rate_order': cur_rate_order, 'cur_rate_price': cur_rate_price}
    return render_to_response('mapshop/product_list.html', context, RequestContext(request))



def product_detail(request,slug):
    u''' 
        Детальная информация о товаре
    '''
    product = get_object_or_404(Product,name_slug=slug) 
    similar = Product.objects.filter(category=product.category).order_by('-rate')[0:20]
    context = {'p': product, 'similar': similar}
    return render_to_response('mapshop/product_detail.html', context, RequestContext(request))

def kiosk_list(request,order_id=0):
    u''' 
        Отображение всех киосков 
    '''
    kiosk_list = Kiosk.objects.all()
    #try:
    order = Order.objects.get(pk=order_id)
    title = u'Выбор киоска для заказа № %s' % order_id
    #except:
    #    pass
    context = {'kiosk_list': kiosk_list, 'title': title, 'order': order}
    return render_to_response('mapshop/kiosk_list.html', context, RequestContext(request))


def finish_order(request,order_id):
    u''' 
        Заключительная фаза заказа с формой данных о клиенте
    '''
    order= get_object_or_404(Order,id=order_id)
    if request.method == 'POST':
        form = ClientForm(request.POST)
        if form.is_valid():
            client = form.save()
            order.status = u'Ожидает оплаты'
            order.session = 'done'
            order.save()
            return HttpResponseRedirect('/thanks/')
    else:
        if request.user.is_authenticated():
            client = get_client_or_create(request.user)
            form = ClientForm(instance=client)
        else:
            form = ClientForm()

    context = {'o': order, 'form': form}
    return render_to_response('mapshop/finish_order.html', context, RequestContext(request))


def thanks(request):
    u''' 
        Страница благодарности
    '''
    context = {}
    return render_to_response('mapshop/thanks.html', context, RequestContext(request))






# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'Order.client'
        db.alter_column(u'mapshop_order', 'client_id', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Client'], null=True))

        # Changing field 'Order.session'
        db.alter_column(u'mapshop_order', 'session', self.gf('django.db.models.fields.CharField')(max_length=250, null=True))

    def backwards(self, orm):

        # Changing field 'Order.client'
        db.alter_column(u'mapshop_order', 'client_id', self.gf('django.db.models.fields.related.ForeignKey')(default=0, to=orm['mapshop.Client']))

        # Changing field 'Order.session'
        db.alter_column(u'mapshop_order', 'session', self.gf('django.db.models.fields.CharField')(default=0, max_length=250))

    models = {
        u'mapshop.category': {
            'Meta': {'object_name': 'Category'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'name_slug': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'})
        },
        u'mapshop.client': {
            'Meta': {'object_name': 'Client'},
            'account_org': ('django.db.models.fields.CharField', [], {'max_length': '16'}),
            'add_phone': ('django.db.models.fields.CharField', [], {'max_length': '11', 'null': 'True', 'blank': 'True'}),
            'address_org': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'bank_org': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'bik_org': ('django.db.models.fields.CharField', [], {'max_length': '9'}),
            'birthday': ('django.db.models.fields.DateField', [], {}),
            'cor_account_org': ('django.db.models.fields.CharField', [], {'max_length': '16'}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'inn_org': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'is_organization': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'kpp_org': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'name_org': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'notice_email': ('django.db.models.fields.BooleanField', [], {}),
            'notice_phone': ('django.db.models.fields.BooleanField', [], {}),
            'phone': ('django.db.models.fields.CharField', [], {'max_length': '11', 'null': 'True', 'blank': 'True'}),
            'postal_index_org': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'surname': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'treatment': ('django.db.models.fields.CharField', [], {'default': "u'\\u0423\\u0432\\u0430\\u0436\\u0430\\u0435\\u043c\\u044b\\u0439'", 'max_length': '10'})
        },
        u'mapshop.kiosk': {
            'Meta': {'object_name': 'Kiosk'},
            'address': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'foto': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'latitude': ('django.db.models.fields.FloatField', [], {}),
            'longitude': ('django.db.models.fields.FloatField', [], {}),
            'mnemonic': ('django.db.models.fields.CharField', [], {'max_length': '5'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'scheduler': ('django.db.models.fields.CharField', [], {'default': "'\\xd1\\x81 9 \\xd0\\xb4\\xd0\\xbe 6 \\xd0\\xb2 \\xd0\\xb1\\xd1\\x83\\xd0\\xb4\\xd0\\xbd\\xd0\\xb8'", 'max_length': '200'})
        },
        u'mapshop.order': {
            'Meta': {'object_name': 'Order'},
            'client': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Client']", 'null': 'True', 'blank': 'True'}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'kiosk': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Kiosk']", 'null': 'True', 'blank': 'True'}),
            'session': ('django.db.models.fields.CharField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
            'status': ('django.db.models.fields.CharField', [], {'default': "u'\\u041d\\u043e\\u0432\\u044b\\u0439'", 'max_length': '10'})
        },
        u'mapshop.orderitem': {
            'Meta': {'object_name': 'OrderItem'},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Order']"}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        },
        u'mapshop.preorder': {
            'Meta': {'object_name': 'Preorder'},
            'client': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Client']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        },
        u'mapshop.product': {
            'Meta': {'object_name': 'Product'},
            'available': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Category']", 'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'price': ('django.db.models.fields.DecimalField', [], {'max_digits': '6', 'decimal_places': '2'}),
            'rate': ('django.db.models.fields.PositiveSmallIntegerField', [], {'default': '0'})
        },
        u'mapshop.productimages': {
            'Meta': {'object_name': 'ProductImages'},
            'cropping': (u'django.db.models.fields.CharField', [], {'default': "u''", 'max_length': '255', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'is_main': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        }
    }

    complete_apps = ['mapshop']


# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Kiosk'
        db.create_table(u'mapshop_kiosk', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('address', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('foto', self.gf('django.db.models.fields.files.ImageField')(max_length=100)),
            ('mnemonic', self.gf('django.db.models.fields.CharField')(max_length=5)),
            ('latitude', self.gf('django.db.models.fields.FloatField')()),
            ('longitude', self.gf('django.db.models.fields.FloatField')()),
        ))
        db.send_create_signal(u'mapshop', ['Kiosk'])

        # Adding model 'Product'
        db.create_table(u'mapshop_product', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('price', self.gf('django.db.models.fields.DecimalField')(max_digits=6, decimal_places=2)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('available', self.gf('django.db.models.fields.BooleanField')()),
        ))
        db.send_create_signal(u'mapshop', ['Product'])

        # Adding model 'ProductImages'
        db.create_table(u'mapshop_productimages', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('product', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Product'])),
            ('image', self.gf('django.db.models.fields.files.ImageField')(max_length=100)),
        ))
        db.send_create_signal(u'mapshop', ['ProductImages'])

        # Adding model 'Client'
        db.create_table(u'mapshop_client', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=75)),
            ('phone', self.gf('django.db.models.fields.CharField')(max_length=11)),
            ('notice_email', self.gf('django.db.models.fields.BooleanField')()),
            ('notice_phone', self.gf('django.db.models.fields.BooleanField')()),
            ('created_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal(u'mapshop', ['Client'])

        # Adding model 'Order'
        db.create_table(u'mapshop_order', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('status', self.gf('django.db.models.fields.CharField')(default=u'\u041d\u043e\u0432\u044b\u0439', max_length=10)),
            ('client', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Client'])),
            ('kiosk', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Kiosk'])),
            ('created_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal(u'mapshop', ['Order'])

        # Adding model 'OrderItem'
        db.create_table(u'mapshop_orderitem', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('order', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Order'])),
            ('product', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Product'])),
            ('created_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal(u'mapshop', ['OrderItem'])


    def backwards(self, orm):
        # Deleting model 'Kiosk'
        db.delete_table(u'mapshop_kiosk')

        # Deleting model 'Product'
        db.delete_table(u'mapshop_product')

        # Deleting model 'ProductImages'
        db.delete_table(u'mapshop_productimages')

        # Deleting model 'Client'
        db.delete_table(u'mapshop_client')

        # Deleting model 'Order'
        db.delete_table(u'mapshop_order')

        # Deleting model 'OrderItem'
        db.delete_table(u'mapshop_orderitem')


    models = {
        u'mapshop.client': {
            'Meta': {'object_name': 'Client'},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'notice_email': ('django.db.models.fields.BooleanField', [], {}),
            'notice_phone': ('django.db.models.fields.BooleanField', [], {}),
            'phone': ('django.db.models.fields.CharField', [], {'max_length': '11'})
        },
        u'mapshop.kiosk': {
            'Meta': {'object_name': 'Kiosk'},
            'address': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'foto': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'latitude': ('django.db.models.fields.FloatField', [], {}),
            'longitude': ('django.db.models.fields.FloatField', [], {}),
            'mnemonic': ('django.db.models.fields.CharField', [], {'max_length': '5'})
        },
        u'mapshop.order': {
            'Meta': {'object_name': 'Order'},
            'client': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Client']"}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'kiosk': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Kiosk']"}),
            'status': ('django.db.models.fields.CharField', [], {'default': "u'\\u041d\\u043e\\u0432\\u044b\\u0439'", 'max_length': '10'})
        },
        u'mapshop.orderitem': {
            'Meta': {'object_name': 'OrderItem'},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Order']"}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        },
        u'mapshop.product': {
            'Meta': {'object_name': 'Product'},
            'available': ('django.db.models.fields.BooleanField', [], {}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'price': ('django.db.models.fields.DecimalField', [], {'max_digits': '6', 'decimal_places': '2'})
        },
        u'mapshop.productimages': {
            'Meta': {'object_name': 'ProductImages'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        }
    }

    complete_apps = ['mapshop']


# -*- coding: utf-8 -*-
from django.db import models
from image_cropping import ImageRatioField
from django.utils.safestring import mark_safe
from easy_thumbnails.files import get_thumbnailer
import pytils
from django.core.urlresolvers import reverse
from mptt.models import MPTTModel, TreeForeignKey
from django.db.models.signals import post_save




class Kiosk(models.Model):
    u''' Класс Киоск содержит все данные о киоске (адрес, фото, мнемонику, широту, долготу) '''
    address = models.CharField(max_length=200)
    foto = models.ImageField(upload_to='media')
    mnemonic = models.CharField(max_length=5)
    latitude = models.FloatField()
    longitude = models.FloatField()
    name = models.CharField(max_length=200)
    scheduler = models.CharField(max_length=200, default='с 9 до 6 в будни')
    def __unicode__(self):
        return self.name

class Category(MPTTModel):
    ''' Класс категори товаров'''
    name = models.CharField(max_length=200)
    name_slug = models.CharField(verbose_name='Name slug',max_length=250, blank=True)
    parent = TreeForeignKey('self', null=True, blank=True, related_name='children', db_index=True)
    def get_absolute_url(self):
       return reverse("catalog_filter", kwargs={"slug": self.name_slug})
    def __unicode__(self):
        return self.name
    def save(self, **kwargs):
        if not self.id:
            self.name_slug = pytils.translit.slugify(self.name)
        return super(Category, self).save(**kwargs)


class Product(models.Model):
    u''' Класс Продукт содержит данные о товарах (имя, фото, цену, описание, наличие товара)'''
    __original_ammount = None

    def __init__(self, *args, **kwargs):
        super(Product, self).__init__(*args, **kwargs)
        self.__original_ammount = self.ammount
    name = models.CharField(max_length=200)
    price = models.DecimalField(max_digits=6, decimal_places=2, verbose_name=u"Стоимость (руб)")
    description = models.CharField(max_length=200)
    ammount = models.PositiveSmallIntegerField(default=0) 
    rate = models.PositiveSmallIntegerField(default=0)
    category = models.ForeignKey(Category, null=True, blank=True)
    name_slug = models.CharField(verbose_name='Name slug',max_length=250, blank=True)
    def get_absolute_url(self):
       return reverse("product_detail", kwargs={"slug": self.name_slug})
    @property
    def thumb(self):
        image = ProductImages.objects.get(is_main=True,product=self)
        thumbnail_url = get_thumbnailer(image.image).get_thumbnail({
            'size': (100, 100),
            'box': image.cropping,
            'crop': True,
            'detail': True,
        }).url
        return mark_safe(u'<img src="%s" />' % thumbnail_url)
    def __unicode__(self):
        return self.name
    def save(self, **kwargs):
        from mapshop.tasks import test_task
        if not self.id:
            self.name_slug = pytils.translit.slugify(self.name)
        if self.ammount != self.__original_ammount and self.__original_ammount==0:
            test_task.delay(self)
            self.__original_ammount = self.ammount
        return super(Product, self).save(**kwargs)



class ProductImages(models.Model):
    from easy_thumbnails.files import get_thumbnailer
    u''' картинки товаров '''
    product = models.ForeignKey('Product')
    image  = models.ImageField(upload_to='product', verbose_name=u'Изображение')
    cropping = ImageRatioField('image', '430x360')
    is_main = models.BooleanField(default=False) 
    @property
    def thumb(self):
        #try:
        thumbnail_url = get_thumbnailer(self.image).get_thumbnail({
            'size': (100, 100),
            'box': self.cropping,
            'crop': True,
            'detail': True,
        }).url
        return mark_safe(u'<img src="%s" />' % thumbnail_url)
        #except:
        #    return 'no image'
    def save(self, **kwargs):
        if not self.id:
            if not ProductImages.objects.filter(product=self.product).exists():
                self.is_main = True
        return super(ProductImages, self).save(**kwargs)


   
class Client(models.Model):
    u''' Класс Клиент содержит данные о клиенте (емайл, телефон, параметр уведомления по емайлу, параметр уведомления по телефону)  '''
    surname = models.CharField(max_length=100, null=True, blank=True, verbose_name=u'Фамилия')
    name = models.CharField(max_length=100, null=True, blank=True, verbose_name=u'Имя')
    phone = models.CharField(max_length=11, null=True, blank=True, verbose_name=u'Телефон')
    add_phone = models.CharField(max_length=11, null=True, blank=True, verbose_name=u'Дополнительный телефон')
    email = models.EmailField(verbose_name=u'Email')
    birthday = models.DateField(null=True, blank=True, verbose_name=u'Дата рождения')
    notice_email = models.BooleanField(default=True, verbose_name=u'Email для уведомлений')
    notice_phone = models.BooleanField(default=True, verbose_name=u'Телефон для СМС уведомлений')
    created_at = models.DateTimeField(auto_now_add=True)
    is_organization = models.BooleanField(default='True', verbose_name=u'Организация?')
    name_org = models.CharField(max_length=100, null=True, blank=True, verbose_name=u'Наименование организации')
    address_org = models.CharField(max_length=200, null=True, blank=True, verbose_name=u'Юридический адрес организации')
    postal_index_org = models.CharField(max_length=10, null=True, blank=True, verbose_name=u'Почтовый индекс')
    inn_org = models.CharField(max_length=10, null=True, blank=True, verbose_name=u'ИНН')
    kpp_org = models.CharField(max_length=10, null=True, blank=True, verbose_name=u'КПП')
    account_org = models.CharField(max_length=16, null=True, blank=True, verbose_name=u'Р/с')
    bank_org = models.CharField(max_length=100, null=True, blank=True, verbose_name=u'Банк')
    cor_account_org = models.CharField(max_length=16, null=True, blank=True, verbose_name=u'Корр. счет')
    bik_org = models.CharField(max_length=9, null=True, blank=True, verbose_name=u'БИК')
    user_id = models.IntegerField(default=0, null=True, blank=True, verbose_name=u'Пользователь')
    kiosk = models.ForeignKey('Kiosk', null=True, blank=True)
    def __unicode__(self):
        return self.name


class Order(models.Model):
    u''' заказы по клиенту '''
    STATUSES = (
        (u'Новый', u'Новый'),
        (u'Киоск выбран', u'Киоск выбран'),
        (u'Ожидает оплаты', u'Ожидает оплаты'),
        (u'Оплачен', u'Оплачен'),
        (u'Доставка', u'Доставка'),
        (u'Доставлен', u'Доставлен'),
        (u'Отказ', u'Отказ'),
    )
    status = models.CharField(verbose_name=u'Статус заказа',
                                    choices=STATUSES,
                                    default=u'Новый',
                                    max_length=20)
    client = models.ForeignKey('Client', null=True, blank=True) 
    kiosk = models.ForeignKey('Kiosk', null=True, blank=True) 
    created_at = models.DateTimeField(auto_now_add=True)
    session = models.CharField(max_length=250, null=True, blank=True)
    @property
    def total(self):
        t = 0
        for i in self.orderitem_set.all():
            t = t + (i.product.price*i.ammount)
        return t
    

class OrderItem(models.Model):
    u'''Элементы заказа'''
    order = models.ForeignKey('Order')
    product = models.ForeignKey('Product') 
    created_at = models.DateTimeField(auto_now_add=True)
    ammount = models.IntegerField(default=1)
    

class Preorder(models.Model):
    u'''Предзаказ содержит данные о предзаказах по клиентам'''
    TYPE = (
        ('phone', 'phone'),
        ('email', 'email'),
    )
    product = models.ForeignKey('Product')
    contact =  models.CharField(max_length=250, null=True, blank=True)
    type = models.CharField(verbose_name=u'Тип предзаказа',
                                    choices=TYPE,
                                    default='email',
                                    max_length=5)
    created_at = models.DateTimeField(auto_now_add=True)
    class Meta:
        unique_together = ('product', 'contact', 'type')



def get_client_or_create(user):
    try:
        c = Client.objects.get(user_id=user.id)
    except:
        c = Client()
        c.name = user.username
        c.email = user.email
        c.user_id = user.id
        c.save()
    return c
    

from django.db.models.signals import post_save
from django.dispatch import receiver

@receiver(post_save, sender = Order)
def manage_with_order(instance, **kwargs):
    print '---------------------------------------work with order %s' % instance.pk












# -*- coding: utf-8 -*-
from django.shortcuts import render
from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from mapshop.forms import ProductFilterForm
from mapshop.models import Category, Product, Kiosk, Order, Client, get_client_or_create
from django.http import HttpResponseRedirect
from django.views.decorators.csrf import csrf_exempt
from django.utils import simplejson
from django.http import HttpResponse

@csrf_exempt
def product_edit(request):
    status = '0'
    message = 'Ok'
    indata = simplejson.loads(request.body)

    try:
        product = Product.objects.get(pk = indata['product_id'])
    except:
        status = '1'
        message = 'Could not find product by ID'   

    try:
        av = indata['ammount']
        product.ammount = av
        message = 'Product %s setting ammount in value %s !!!' % (product,av)
        product.save()
    except:
        pass
        
    out = {
        'status': status,
        'message': message,
    }
    outdata = simplejson.dumps(out)
    return HttpResponse(outdata, mimetype='application/json')



@csrf_exempt
def product_bye(request):
    indata = simplejson.loads(request.body)
    print 'bye %s ammount %s ' % (indata['product_id'], indata['ammount'])
    out = {
        'status': 0,
        'message': 'Ok',
    }
    outdata = simplejson.dumps(out)
    return HttpResponse(outdata, mimetype='application/json')




# -*- coding: utf-8 -*-
MIN_SUMM = 10 # минимальная сумма заказа, влияющая на ссылку продолжения заказа в корзине
EMAIL_REPLY = 'noreply@pressa.ru' # отправитель уведомлений
######DEV MODE##################
API_CREATE_USER = 'http://localhost:8008/api/create/user' # create user on the site-integrator
API_BILLING_PAGE = 'http://localhost:8008/api/billing?sum={{sum}}&ms_order_id={{ms_order_id}}' # redirect to the site-integrator's billing page
API_SUCCESS_PAYMENT = 'http://localhost:8008/api/success/payment' # request from site-integrator about successfull payment

######PROD MODE##################
#API_CREATE_USER = 'http://pressa.ru/mapshopapi/create/user' # create user on the site-integrator
#API_BILLING_PAGE = 'http://pressa.ru/ru/billing/payment?sum={{sum}}&ms_order_id={{ms_order_id}}' # redirect to the site-integrator's billing page
#API_SUCCESS_PAYMENT = 'http://pressa.ru/mapshopapi/success/payment' # request from site-integrator about successfull payment



# -*- coding: utf-8 -*-
import logging
from optparse import make_option
from django.core.exceptions import ObjectDoesNotExist
from django.core.management.base import BaseCommand
from mapshop.models import Category, Product, ProductImages, Kiosk , Order, Client
from django.core.files import File
from random import randint
import csv
from django.contrib.auth.models import User
from mapshop.management.commands.utils import *

#logger = logging.getLogger(__name__)


class Command(BaseCommand):

    def handle(self, *args, **options):
        
        print 'start'
        
        ProductImages.objects.all().delete()
        Product.objects.all().delete()
        Category.objects.all().delete()
        Order.objects.all().delete()
        Client.objects.all().delete()
        User.objects.all().exclude(username='admin').delete()
        l = [ 'food','slippers']
        
        for i in l:
            o = Category()
            o.name = i
            o.save()
            cnt = 0
            for n in range(10):
                cnt = cnt  + 1 
                p = Product()
                p.category = o
                p.price = n
                p.rate = randint(0,90)
                p.name = 'Product %s %s' % (n,o.name)
                p.description = u'Описание продукта %s из категории %s у которого рейтинг %s' % (p.name,o.name,p.rate)
                p.save()
                for im in range(3):
                    path = 'fixture/test.jpg'
                    #import pdb; pdb.set_trace()
                    name = 'test.jpg' 
                    f = open(path, 'r')
                    file = File(f)
                    im = ProductImages()
                    im.product = p
                    im.image.save(name,file)
                    im.save()
                    print 'process with image %s' % im
                print 'process with %s' % n
        
        for u in ['dima','viktor','alex']:
            client = create_user(u)
            product = Product.objects.get(pk=1)
            create_preloader(client, product)
            
        #o = Order()
        #o.save()
        #print 'order was created'

      

        print 'done'

'''
import tempfile
from django.core import files
lf = tempfile.NamedTemporaryFile()
for block in open('path','r'):
    if not block:
        break
    lf.write(block)
j.cover.save(file_name, files.File(lf))

'''

       



# -*- coding: utf-8 -*-
from celery import task
from termcolor import colored
from mapshop.models import Preorder
from django.template import loader, Context
from django.contrib.sites.models import get_current_site
from django.contrib.sites.models import Site
from django.core.mail import EmailMultiAlternatives
from settings import EMAIL_REPLY

def sendm(email, title, body):
    msg = EmailMultiAlternatives(title, body, EMAIL_REPLY, (email,))
    msg.content_subtype = "html"
    msg.send() 


@task(name='test_task')
def test_task(product):
    site = Site.objects.get_current()
    for i in Preorder.objects.all().filter(type='email'):
        t = loader.get_template('mapshop/mail_templates/remaind_mail.tpl')
        print colored('send email to %s' % i.contact, 'red')
        link_url = ''.join(['http://', site.domain, i.product.get_absolute_url()])
        link_html = '<a href="%s">%s</a>' % (link_url,i.product)
        c = Context({'site_name': site.name, 'product': i.product, 'link': link_html})
        print colored(t.render(c), 'yellow')
        sendm(i.contact,u'Уведомление о поступлении товара', t.render(c))
    for i in Preorder.objects.all().filter(type='phone'):
        print colored('Sending SMS to %s' % i.contact, 'white')



# -*- coding: utf-8 -*-
from django_ajax.decorators import ajax
from django.shortcuts import render
from mapshop.models import Category, Product, Kiosk, Order, OrderItem, get_client_or_create, Preorder, Client


def get_cart_html(user):
    out = u'<h3> История заказов </h3>'
    out = out + u'<table class="mapshop_cart_table"><tr> <th>Дата</th> <th>Перечень товаров</th> <th>Общая стоимость</th> <th>Статус</th> </tr>'
    client = Client.objects.get(user_id=user.id)
    orders = Order.objects.filter(client=client)
    for o in orders:
        items = '<ul class="mapshop_items">'
        for p in o.orderitem_set.all():
            items = items + '<li>%s</li>' % p.product.name
        items = items + '</ul>'
        out = out + u'<tr><td>%s</td> <td>%s</td> <td>%s руб.</td> <td>%s</td> </tr>' % (o.created_at.strftime('%d.%m.%Y'), items, o.total, o.status,)
    out = out + u'</table>'
    return out

@ajax
def cart_show(request):
    '''  Отображение истории заказов '''
    data = {
            'inner-fragments': { '#mapshop_cart': get_cart_html(request.user)},       
           } 
    return data 

@ajax
def preorder_save(request):
    '''  Cохранение заявки на уведомление о появлении товара '''
    data = {}
    phone = request.GET.get('phone','0')
    email = request.GET.get('email','0')
    product = Product.objects.get(pk=request.GET.get('product_id','0'))
    if phone:
        try:
            p = Preorder.objects.create(contact=phone,product=product,type='phone')
            data = { 'append-fragments': {'#message': '<p>Заявка сохранена!</p>'}}
        except:
            data = {
                    'inner-fragments': { '#error': 'Заявка с такими даннымиы уже существует!'},       
                   }               
    if email:
        try:
            p = Preorder.objects.create(contact=email,product=product,type='email')
            data = { 'append-fragments': {'#message': '<p>Заявка сохранена!</p>'}}
        except:
            data = {
                    'inner-fragments': { '#error': 'Заявка с такими данными уже существует!'},       
                   }     
    return data 
    #try:
    #    p = Preorder.objects.create(pk=request.GET['item_id'])
    #except:
    #    pass

@ajax
def del_product_from_cart(request):
    '''  Удаление товара из корзины и вывод содержимого корзины в html блок <table id="my_busket"></table> '''
    try:
        o = OrderItem.objects.get(pk=request.GET['item_id'])
        o.delete()
    except:
        pass
    session = request.session.session_key
    data = {
            'inner-fragments': { '#my_basket': get_basket_html_by_session_key(session) },       
           }     
    return data

@ajax
def add_product_to_cart(request):
    '''  Добавление товара в корзину и вывод содержимого корзины в html блок <table id="my_busket"></table> '''
    session = request.session.session_key
    #import pdb; pdb.set_trace()
    try:
        product  = Product.objects.get(pk=request.GET.get('product_id',0))
        try:
            order = Order.objects.get(session=session)
        except:
            order = Order()
            order.session = session
            if request.user.is_authenticated():
                client = get_client_or_create(request.user)
                order.client = client
            order.save()
        try:
            item = OrderItem.objects.get(order=order, product=product)
            item.ammount = item.ammount+1
            item.save()
        except:
            item = OrderItem()
            item.product = product
            item.order = order
            item.save()
    except:
        product = None
    data = {
            'inner-fragments': { '#my_basket': get_basket_html_by_session_key(session) },       
           }     
    return data


def get_basket_html_by_session_key(session):
    '''  Получение html кода корзины по идентификатору сессии '''
    from settings import MIN_SUMM
    out = ''
    total = 0
    #import pdb; pdb.set_trace()
    try:
        order = Order.objects.get(session=session)
        if order.orderitem_set.all().count() == 0:
            return u'<b> корзина пуста </b>'
        out = u'<table class="mapshop_basket"><tr><th>Название</th><th>кол-во</th><th>цена</th><th></th></tr>'
        for i in order.orderitem_set.all():
            total = total + (i.ammount*i.product.price)
            out = out + u'<tr><td>%s</td><td>%s</td><td>%s руб.</td><td><a href="#" onclick="return false" data-id=%s class="del_product_from_cart" >X</td></tr>' % (i.product, i.ammount, i.product.price, i.id) 
        out = out + u'<tr><td colspan=3>Итого:</td><td>%s</td></tr>' % total
        out = out + u'</table>'
        if total<MIN_SUMM:
            out = out + u'<span style="color: red"> минимальная стоимость заказа %s </span>' % MIN_SUMM    
        else:
            out = out + u'<a href="/kiosk/list/%s.html">Оформить заказ</a>' % order.id
    except:
        out = u'<b> корзина пуста </b>'
    return out





@ajax
def getinfo_kiosk(request):
    print '----------------------------------%s' % request.GET['kiosk_id']
    ''' выбор киоска  '''
    out = ''
    #try:
    kiosk = Kiosk.objects.get(pk=request.GET['kiosk_id'])
    order = Order.objects.get(pk=request.GET['order_id'])
    if request.user.is_authenticated():
        client = Client.objects.get(user_id=request.user.id)
        client.kiosk = kiosk
        client.save()
    order.kiosk = kiosk
    order.status = u'Киоск выбран'
    order.save()
    context = {'kiosk_name' : kiosk.name,
               'kiosk_address' : kiosk.address,
               'kiosk_scheduler' : kiosk.scheduler,
               'order_id' : request.GET['order_id'],
               'kiosk_foto' : kiosk.foto,
              }
    out = render(request, 'kiosk.html', context)
    #except:
    #    out = 'object does not found'
  
    data = {
            'inner-fragments': { '#kiosk_info': out }
           }
    return data

'''

        <script type="text/javascript" src="{% static 'django_ajax/js/jquery.ajax.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'django_ajax/js/jquery.ajax-plugin.min.js' %}"></script>

        <script type="text/javascript" src="{% static 'mapsho/static/driver.js' %}"></script>
    



        //// Close private chat **************************
         $('#content').on('click', function(e) {
          
            e.preventDefault();
            
                 ajaxGet('{% url 'ajax-close-private-chat' %}', { 'room_id': room_id }, function(content){ alert(content.myvar) });     
                ajaxGet('/myurl', { 'room_id': room_id }, function(content){});         
            
        });   
        //**************************************************




'''



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from decimal import Decimal
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Preorder'
        db.create_table(u'mapshop_preorder', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('product', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Product'])),
            ('client', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['mapshop.Client'])),
        ))
        db.send_create_signal(u'mapshop', ['Preorder'])

        # Adding field 'Client.treatment'
        db.add_column(u'mapshop_client', 'treatment',
                      self.gf('django.db.models.fields.CharField')(default=u'\u0423\u0432\u0430\u0436\u0430\u0435\u043c\u044b\u0439', max_length=10),
                      keep_default=False)

        # Adding field 'Client.surname'
        db.add_column(u'mapshop_client', 'surname',
                      self.gf('django.db.models.fields.CharField')(max_length=100, null=True, blank=True),
                      keep_default=False)

        # Adding field 'Client.name'
        db.add_column(u'mapshop_client', 'name',
                      self.gf('django.db.models.fields.CharField')(max_length=100, null=True, blank=True),
                      keep_default=False)

        # Adding field 'Client.add_phone'
        db.add_column(u'mapshop_client', 'add_phone',
                      self.gf('django.db.models.fields.CharField')(max_length=11, null=True, blank=True),
                      keep_default=False)

        # Adding field 'Client.birthday'
        db.add_column(u'mapshop_client', 'birthday',
                      self.gf('django.db.models.fields.DateField')(default=datetime.datetime(2015, 6, 2, 0, 0)),
                      keep_default=False)

        # Adding field 'Client.is_organization'
        db.add_column(u'mapshop_client', 'is_organization',
                      self.gf('django.db.models.fields.BooleanField')(default=True),
                      keep_default=False)

        # Adding field 'Client.name_org'
        db.add_column(u'mapshop_client', 'name_org',
                      self.gf('django.db.models.fields.CharField')(default=datetime.datetime(2015, 6, 2, 0, 0), max_length=100),
                      keep_default=False)

        # Adding field 'Client.address_org'
        db.add_column(u'mapshop_client', 'address_org',
                      self.gf('django.db.models.fields.CharField')(default=datetime.datetime(2015, 6, 2, 0, 0), max_length=200),
                      keep_default=False)

        # Adding field 'Client.postal_index_org'
        db.add_column(u'mapshop_client', 'postal_index_org',
                      self.gf('django.db.models.fields.DecimalField')(default=Decimal('0.00'), max_digits=5, decimal_places=2),
                      keep_default=False)

        # Adding field 'Client.inn_org'
        db.add_column(u'mapshop_client', 'inn_org',
                      self.gf('django.db.models.fields.DecimalField')(default=Decimal('0.00'), max_digits=10, decimal_places=2),
                      keep_default=False)

        # Adding field 'Client.kpp_org'
        db.add_column(u'mapshop_client', 'kpp_org',
                      self.gf('django.db.models.fields.DecimalField')(default=Decimal('0.00'), max_digits=10, decimal_places=2),
                      keep_default=False)

        # Adding field 'Client.account_org'
        db.add_column(u'mapshop_client', 'account_org',
                      self.gf('django.db.models.fields.DecimalField')(default=Decimal('0.00'), max_digits=16, decimal_places=2),
                      keep_default=False)

        # Adding field 'Client.bank_org'
        db.add_column(u'mapshop_client', 'bank_org',
                      self.gf('django.db.models.fields.CharField')(default=datetime.datetime(2015, 6, 2, 0, 0), max_length=100),
                      keep_default=False)

        # Adding field 'Client.cor_account_org'
        db.add_column(u'mapshop_client', 'cor_account_org',
                      self.gf('django.db.models.fields.DecimalField')(default=Decimal('0.00'), max_digits=16, decimal_places=2),
                      keep_default=False)

        # Adding field 'Client.bik_org'
        db.add_column(u'mapshop_client', 'bik_org',
                      self.gf('django.db.models.fields.DecimalField')(default=Decimal('0.00'), max_digits=9, decimal_places=2),
                      keep_default=False)


        # Changing field 'Client.phone'
        db.alter_column(u'mapshop_client', 'phone', self.gf('django.db.models.fields.CharField')(max_length=11, null=True))

    def backwards(self, orm):
        # Deleting model 'Preorder'
        db.delete_table(u'mapshop_preorder')

        # Deleting field 'Client.treatment'
        db.delete_column(u'mapshop_client', 'treatment')

        # Deleting field 'Client.surname'
        db.delete_column(u'mapshop_client', 'surname')

        # Deleting field 'Client.name'
        db.delete_column(u'mapshop_client', 'name')

        # Deleting field 'Client.add_phone'
        db.delete_column(u'mapshop_client', 'add_phone')

        # Deleting field 'Client.birthday'
        db.delete_column(u'mapshop_client', 'birthday')

        # Deleting field 'Client.is_organization'
        db.delete_column(u'mapshop_client', 'is_organization')

        # Deleting field 'Client.name_org'
        db.delete_column(u'mapshop_client', 'name_org')

        # Deleting field 'Client.address_org'
        db.delete_column(u'mapshop_client', 'address_org')

        # Deleting field 'Client.postal_index_org'
        db.delete_column(u'mapshop_client', 'postal_index_org')

        # Deleting field 'Client.inn_org'
        db.delete_column(u'mapshop_client', 'inn_org')

        # Deleting field 'Client.kpp_org'
        db.delete_column(u'mapshop_client', 'kpp_org')

        # Deleting field 'Client.account_org'
        db.delete_column(u'mapshop_client', 'account_org')

        # Deleting field 'Client.bank_org'
        db.delete_column(u'mapshop_client', 'bank_org')

        # Deleting field 'Client.cor_account_org'
        db.delete_column(u'mapshop_client', 'cor_account_org')

        # Deleting field 'Client.bik_org'
        db.delete_column(u'mapshop_client', 'bik_org')


        # Changing field 'Client.phone'
        db.alter_column(u'mapshop_client', 'phone', self.gf('django.db.models.fields.CharField')(default=datetime.datetime(2015, 6, 2, 0, 0), max_length=11))

    models = {
        u'mapshop.client': {
            'Meta': {'object_name': 'Client'},
            'account_org': ('django.db.models.fields.DecimalField', [], {'max_digits': '16', 'decimal_places': '2'}),
            'add_phone': ('django.db.models.fields.CharField', [], {'max_length': '11', 'null': 'True', 'blank': 'True'}),
            'address_org': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'bank_org': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'bik_org': ('django.db.models.fields.DecimalField', [], {'max_digits': '9', 'decimal_places': '2'}),
            'birthday': ('django.db.models.fields.DateField', [], {}),
            'cor_account_org': ('django.db.models.fields.DecimalField', [], {'max_digits': '16', 'decimal_places': '2'}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'inn_org': ('django.db.models.fields.DecimalField', [], {'max_digits': '10', 'decimal_places': '2'}),
            'is_organization': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'kpp_org': ('django.db.models.fields.DecimalField', [], {'max_digits': '10', 'decimal_places': '2'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'name_org': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'notice_email': ('django.db.models.fields.BooleanField', [], {}),
            'notice_phone': ('django.db.models.fields.BooleanField', [], {}),
            'phone': ('django.db.models.fields.CharField', [], {'max_length': '11', 'null': 'True', 'blank': 'True'}),
            'postal_index_org': ('django.db.models.fields.DecimalField', [], {'max_digits': '5', 'decimal_places': '2'}),
            'surname': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'treatment': ('django.db.models.fields.CharField', [], {'default': "u'\\u0423\\u0432\\u0430\\u0436\\u0430\\u0435\\u043c\\u044b\\u0439'", 'max_length': '10'})
        },
        u'mapshop.kiosk': {
            'Meta': {'object_name': 'Kiosk'},
            'address': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'foto': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'latitude': ('django.db.models.fields.FloatField', [], {}),
            'longitude': ('django.db.models.fields.FloatField', [], {}),
            'mnemonic': ('django.db.models.fields.CharField', [], {'max_length': '5'})
        },
        u'mapshop.order': {
            'Meta': {'object_name': 'Order'},
            'client': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Client']"}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'kiosk': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Kiosk']"}),
            'status': ('django.db.models.fields.CharField', [], {'default': "u'\\u041d\\u043e\\u0432\\u044b\\u0439'", 'max_length': '10'})
        },
        u'mapshop.orderitem': {
            'Meta': {'object_name': 'OrderItem'},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Order']"}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        },
        u'mapshop.preorder': {
            'Meta': {'object_name': 'Preorder'},
            'client': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Client']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        },
        u'mapshop.product': {
            'Meta': {'object_name': 'Product'},
            'available': ('django.db.models.fields.BooleanField', [], {}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'price': ('django.db.models.fields.DecimalField', [], {'max_digits': '6', 'decimal_places': '2'})
        },
        u'mapshop.productimages': {
            'Meta': {'object_name': 'ProductImages'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['mapshop.Product']"})
        }
    }

    complete_apps = ['mapshop']


# -*- coding: utf-8 -*-
from django.conf.urls import patterns, url
import mapshop.views as views


from django.conf.urls import patterns, url

urlpatterns = patterns( '',
    url(r'^product/list/all.html$', 'mapshop.views.product_list', name="catalog_all"),
    url(r'^product/list/(?P<slug>[^\.]+).html$', 'mapshop.views.product_list', name="catalog_filter"),
    url(r'^product/detail/(?P<slug>[^\.]+).html$', 'mapshop.views.product_detail', name="product_detail"),
    url(r'^kiosk/list/(?P<order_id>[^\.]+).html$', 'mapshop.views.kiosk_list', name="kiosk_all"),
    url(r'^finish/order/(?P<order_id>[^\.]+)$', 'mapshop.views.finish_order', name="finish_order"),
    url(r'^thanks/$', 'mapshop.views.thanks'),
    

    ##################AJAX REQUESTS############################
    url(r'^add/to/cart/$', 'mapshop.ajax.add_product_to_cart'),
    url(r'^del/from/cart$', 'mapshop.ajax.del_product_from_cart'),
    url(r'^getinfo/kiosk$', 'mapshop.ajax.getinfo_kiosk'),
    url(r'^preorder/save$', 'mapshop.ajax.preorder_save'),
    url(r'^cart/show$', 'mapshop.ajax.cart_show'),


    ##################API REQUESTS############################
    url(r'^api/product/edit$', 'mapshop.api.product_edit'),
    url(r'^api/product/bye$', 'mapshop.api.product_bye'),


)




# -*- coding: utf-8 -*-
import logging
from optparse import make_option
from django.core.exceptions import ObjectDoesNotExist
from django.core.management.base import BaseCommand
from mapshop.models import Category, Product, ProductImages, Kiosk , Order, Client
from django.core.files import File
from random import randint
import csv
from django.contrib.auth.models import User
from mapshop.management.commands.utils import *
from termcolor import colored
import json
import requests
#logger = logging.getLogger(__name__)


    
    
    

class Command(BaseCommand):

    def handle(self, *args, **options):
        print colored('start test API', 'green', attrs=['reverse', 'blink'])
        product = Product.objects.get(pk=1)
        if product.ammount==0:
            av = '1'
        else:
            av = '0'
        data = {'product_id': '1', 'ammount': av}
        mess = '****request to change availability of %s to None' % product
        url = 'http://localhost:8008/api/product/edit'
        headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
        responce = requests.post(url, data=json.dumps(data), headers=headers).content
        print colored(responce, 'white')
        print colored('stop test API', 'red', attrs=['reverse', 'blink'])

        data = {'product_id': '1', 'ammount': '2'}
        mess = '****request to to bye '
        url = 'http://localhost:8008/api/product/bye'
        headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
        responce = requests.post(url, data=json.dumps(data), headers=headers).content
        print colored(responce, 'white')

       



from setuptools import setup, find_packages

setup(name='django-mapshop',
      version='0.2',
      description='Internet shop with geographic points',
      url='http://github.com/storborg/funniest',
      author='Dmitry Zharikov',
      author_email='zdimon77@gmail.com',
      license='MIT',
      packages=find_packages(exclude=["config"]),
      include_package_data=True,
      zip_safe=False) 



# -*- coding: utf-8 -*-
from django.utils.safestring import mark_safe
from mapshop.models import Category, Product, Client
from django.forms import ModelForm




class ClientForm(ModelForm):
    class Meta:
        model = Client




__author__ = '1'
from django import forms


class ProductFilterForm(forms.Form):
    ASC = '1'
    DSC = '-1'
    ORDER_RATE = '1'
    ORDER_PRICE = '2'
    CHOICES = ((ASC, mark_safe('&#8593;')), (DSC, mark_safe('&#8595;')))
    ORDER_CHOICES = ((ORDER_RATE, u'По рейтингу'), (ORDER_PRICE, u'По цене'))
    category = forms.ModelChoiceField(Category.objects.all(), label=u'Категория', required=False)
    rate = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES, label=u'Рейтинг', required=False)
    price = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES, label=u'Цена', required=False)
    order = forms.ChoiceField(widget=forms.RadioSelect, choices=ORDER_CHOICES, label=u'Порядок сортировки', required=False)

    def __init__(self, *args, **kwargs):
        initial = kwargs.pop('initial', {})
        initial.setdefault('rate', self.ASC)
        initial.setdefault('price', self.ASC)
        initial.setdefault('order', self.ORDER_RATE)
        super(ProductFilterForm, self).__init__(initial=initial, *args, **kwargs)

    def _get_rate_ordering(self):
        return 'rate' if self.cleaned_data.get('rate') == self.ASC else '-rate'

    def _get_price_ordering(self):
        return 'price' if self.cleaned_data.get('price') == self.ASC else '-price'

    def clean_rate(self):
        return self.cleaned_data.get('rate', self.ASC)

    def clean_price(self):
        return self.cleaned_data.get('price', self.ASC)

    def clean_order(self):
        return self.cleaned_data.get('order', self.ORDER_RATE)

    def get_products(self):
        self.full_clean()
        products = Product.objects.all()
        if self.is_bound:
            cleaned_data = self.cleaned_data
            if cleaned_data.get('category'):
                products = products.filter(category=cleaned_data.get('category'))
            _ordering =[]
            _order = cleaned_data.get('order')
            if _order == self.ORDER_RATE:
                _ordering.append(self._get_rate_ordering())
                _ordering.append(self._get_price_ordering())
            else:
                _ordering.append(self._get_price_ordering())
                _ordering.append(self._get_rate_ordering())
            products = products.order_by(*_ordering)
        return products




# -*- coding: utf-8 -*-
import logging
from optparse import make_option
from django.core.exceptions import ObjectDoesNotExist
from django.core.management.base import BaseCommand
from mapshop.models import Category, Product, ProductImages, Kiosk , Order, Client
from django.core.files import File
from random import randint
import csv
from django.contrib.auth.models import User

#logger = logging.getLogger(__name__)


class Command(BaseCommand):

    option_list = BaseCommand.option_list + (
        make_option('-c', dest='count', 
                    default="6", help="Count of record"),

        
    )

    def handle(self, *args, **options):
        cnt = int(options["count"])
        print 'start %s ' % cnt
        Product.objects.all().delete()
        Category.objects.all().delete()
        root = Category.objects.create(name=u'Каталог', parent=None)
        input_file = open("fixture/products.csv", "rb")
        rdr = csv.DictReader(input_file, delimiter=';', fieldnames=['id', 'name0', 'name', 'reference','ost','price', 'cat', 'subcat', 'photo'])
        i=0
        for rec in rdr:
            i = i + 1
            if cnt==i:
                break
            print '%s....product....%s...in process' % (i, rec['name'])
            try:
                cat = Category.objects.get(name=rec['cat'].decode('utf-8'))
            except:
    
                cat = Category.objects.create(name=rec['cat'].decode('utf-8'), parent=root)
            p = Product()
            p.name = rec['name'].decode('utf-8')
            p.category = cat
            p.price = rec['price'].decode('utf-8')
            p.save()
            #root.add_child_node()
        input_file.close()
        print 'done'





from django.contrib.auth.models import User
from mapshop.models import Category, Product, ProductImages, Kiosk , Order, Client, Preorder

def create_user(username):
    u = User()
    u.username = username
    u.password = '123'
    u.save()
    c = Client()
    c.user_id = u.id
    c.name = username
    c.email = '%s@mail.ru' % username
    c.save()
    print 'User %s just has been created!' % username
    return c

def create_preloader(client,product):
    p = Preorder.objects.create(contact=client.email, product=product)
    p = Preorder.objects.create(contact='3456789%s' % client.id, product=product, type='phone')
    print 'Preorder (user: %s product: %s) just has been created!' % (client, product)

    
